package ucolor

import "testing"
import "image/color"

func TestTransparent (test *testing.T) {
	if Transparent(color.NRGBA { A: 255 }) {
		test.Fatal("false positive")
	}
	if !Transparent(color.NRGBA { A: 0 }) {
		test.Fatal("false negative")
	}
}

func TestToRGBA (test *testing.T) {
	rgba := ToRGBA(color.NRGBA { R: 123, G: 100, B: 23, A: 230 })
	if rgba != (color.RGBA { R: 111, G: 90, B: 20, A: 230 }) {
		test.Fatalf("wrong value: %v", rgba)
	}
}

func TestPremultiply (test *testing.T) {
	r, g, b, a := Premultiply(0xFFFF, 0xFFFF, 0xFFFF, 0x8888)
	if r != 0x8888 || g != 0x8888 || b != 0x8888 || a != 0x8888 {
		test.Fatalf("wrong value: %08x %08x %08x %08x", r, g, b, a)
	}
}

func TestUnpremultiply (test *testing.T) {
	r, g, b, a := Unpremultiply(0x8888, 0x8888, 0x8888, 0x8888)
	if r != 0xFFFF || g != 0xFFFF || b != 0xFFFF || a != 0x8888 {
		test.Fatalf("wrong value: %08x %08x %08x %08x", r, g, b, a)
	}
}
